import gtk

class XnatSearchApp(gtk.Window):

    args = None
    results = []

    def init_connection_fields(self):
        self.queryview.host = self.args.host
        self.queryview.credentials = self.args.user

    def __init__(self, args):
        super(XnatSearchApp, self).__init__()

        self.args = args

        self.set_size_request(1000, 500)
        self.set_position(gtk.WIN_POS_CENTER)
        self.connect("destroy", gtk.main_quit)
        self.set_title("xsa")

        vbox_root = gtk.VBox(False, 1)

        hpaned = gtk.HPaned()
        hpaned.set_position(400)
        vbox_root.pack_start(hpaned, True, True, 5)

        def on_search_query(_, host, credentials, root_type, query, labels):

            user, _, passw = credentials.partition(":")

            import xsalogic.datatypereader as type_reader
            fields = type_reader.get_fields_from_labels(labels,root_type)

            import xsalogic.queries as queries
            import xsa.errors as xsa_errors

            try:
                query_results = queries.search_for( host,
                                                    root_type,
                                                    query,
                                                    fields,
                                                    user,
                                                    passw
                                                    )
            except xsa_errors.Error as e:
                md = gtk.MessageDialog( type=gtk.MESSAGE_WARNING,
                                        buttons=gtk.BUTTONS_OK,
                                        message_format=str(e)
                                        )
                md.run()
                md.destroy()
                self.results = []
            except Exception:
                md = gtk.MessageDialog( type=gtk.MESSAGE_WARNING,
                                        buttons=gtk.BUTTONS_OK,
                                        message_format="An unexpected Error was raised."
                                        )
                md.run()
                md.destroy()
                self.results = []
            else:
                self.results = query_results

            self.resultsview.show_data(self.results, root_type)
            self.statusbar.push(0, "%s Results"%len(self.results))
            self.chartview.update_chart(self.results, root_type)


        # left side

        from xsagtk.query_view import QueryView
        self.queryview = QueryView(homogeneous=False, spacing=1)
        self.queryview.connect("send-query", on_search_query)
        hpaned.add1(self.queryview)

        # right site

        vpaned = gtk.VPaned()
        vpaned.set_position(300)
        hpaned.add2(vpaned)

        # results-table

        from xsagtk.results_view import ResultsDownloadView
        self.resultsview = ResultsDownloadView(False,1)
        vpaned.add1(self.resultsview)

        # chart

        from xsagtk.chart_view import ChartView
        self.chartview = ChartView()
        vpaned.add2(self.chartview)

        # statusbar

        self.statusbar = gtk.Statusbar()
        vbox_root.pack_start(self.statusbar, False, False, 0)

        self.add(vbox_root)

        self.init_connection_fields()
        self.show_all()

if __name__ == "__main__":


    from argparse import ArgumentParser
    parser = ArgumentParser(description='search and download gui')
    parser.add_argument('--host', type=str, help='hostname or ip-address (including port).', default="http://localhost:8080")
    parser.add_argument('--user', type=str, help='user:passw', default=":")
    XnatSearchApp(parser.parse_args())
    gtk.gdk.threads_init()
    gtk.main()
